import pyspark
from pipelib.pipeline_components import Pipeline, Orchestrator
from pipelib.pyspark_step import PysparkStep
from pipelib.data_mergers import Joiner
from pipelib.io_providers import CsvInputProvider, CsvOutputProvider
from tealeaf.tealeaf_step import TealeafStep

sc = pyspark.SparkContext()
sqlCtx = pyspark.SQLContext(sc)

pipeline = Pipeline()

joiner = Joiner(join_columns=['SESSION_KEY'])
sliced_joiner = Joiner(join_columns=['SESSION_KEY', 'SUBSESSION_ID'])

step1 = TealeafStep(data_merger=joiner, session_id_column='SESSION_KEY')
step2 = TealeafStep(data_merger=sliced_joiner, session_id_column=['SESSION_KEY', 'SUBSESSION_ID'])
step3 = PysparkStep(data_merger=sliced_joiner, id_column=['SESSION_KEY', 'SUBSESSION_ID'])

step1.slice_sessions(slicer_event_id='payment', subsession_id_column_name='SUBSESSION_ID')

(step2
 .count_event(event_id='click', result_name='ClicksCount')
 .count_event(event_id='scroll', result_name='ScrollCount')
 .count_event(event_id='reviews', result_name='ReviewsCount')
 .check_event(event_id='payment', result_name='Conversion')
 .check_fact_value(event_id='device', value_to_check='PC', result_name='PC')
 .check_fact_value(event_id='device', value_to_check='MOBILE', result_name='MOBILE')
 .count_fact_value(event_id='visit', value_to_count='HOME', result_name='HomeVisits')
 .count_fact_value(event_id='visit', value_to_count='SEARCH', result_name='SearchVisits')
 .get_last_fact_value(event_id='amount', result_name='CartValue')
 .get_fact_value(event_id='country', result_name='Country')
 )

(step3
 .sum_weighted_columns(list_of_columns=['ScrollCount', 'ReviewsCount'], list_of_weights=[0.3, 0.7], result_name='Interest')
 .keep_input_columns(['SESSION_KEY', 'ClicksCount', 'PC', 'MOBILE', 'HomeVisits', 'SearchVisits', 'CartValue', 'Country', 'Conversion', 'SUBSESSION_ID'])
 )

pipeline.add_steps([step1, step2, step3])

inputProvider = CsvInputProvider(read_paths=['../../example_data/merged'], sql_ctx=sqlCtx)
outputProvider = CsvOutputProvider(write_paths=['../../example_data/sliced_audiences'], sql_ctx=sqlCtx)
orchestrator = Orchestrator(input_provider=inputProvider, transformer=pipeline, output_provider=outputProvider)

orchestrator.run()


